//*****************************************************************************
// Description     : Definition of commands for controlling device
// Target Device   : APV8016A
// Target Platform : Linux, C
// Date            : Jan. 2021
// Version         : 1.0
//*****************************************************************************
#ifndef __COMMAND__
#define __COMMAND__


// command address offset per CH
#define DEVICE_OFFSETADDR_CH	(0x0100)

//******************* command address ********************
// command
#define DEVICE_COMMAND_MOD	(0xb4000010)	// measurement mode
#define DEVICE_COMMAND_AQS	(0xb4000014)	// start/stop
#define DEVICE_COMMAND_MTM	(0xb4000016)	// measurement time
#define DEVICE_COMMAND_CLR	(0xb4000040)	// clear data
#define DEVICE_COMMAND_RQH	(0xb400004a)	// request histogram
#define DEVICE_COMMAND_WWN	(0xb400004c)	// write waite number
#define DEVICE_COMMAND_DAC	(0xb400007a)	// DAC monitor

#define DEVICE_COMMAND_ACG	(0xb4000100)	// analog coarse gain
#define DEVICE_COMMAND_ADG	(0xb4000102)	// ADC gain
#define DEVICE_COMMAND_FFD	(0xb4000104)	// Fast diff
#define DEVICE_COMMAND_FFI	(0xb4000106)	// Fast integral
#define DEVICE_COMMAND_SFR	(0xb4000108)	// slow rise time
#define DEVICE_COMMAND_SFP	(0xb400010a)	// slow peaking time
#define DEVICE_COMMAND_FPZ	(0xb400010c)	// fast pole zero
#define DEVICE_COMMAND_SPZ	(0xb400010e)	// slow pole zero
#define DEVICE_COMMAND_FTH	(0xb4000110)	// fast threshold
#define DEVICE_COMMAND_LLD	(0xb4000112)	// LLD
#define DEVICE_COMMAND_ULD	(0xb4000114)	// ULD
#define DEVICE_COMMAND_STH	(0xb4000116)	// slow threshold
#define DEVICE_COMMAND_PUR	(0xb4000118)	// pileup reject
#define DEVICE_COMMAND_POL	(0xb400011a)	// polarity
#define DEVICE_COMMAND_RFL	(0xb4000138)	// filter reset
#define DEVICE_COMMAND_DCG	(0xb400013a)	// digital coarse gain
#define DEVICE_COMMAND_DFG	(0xb400013c)	// digital fine gain
#define DEVICE_COMMAND_TMS	(0xb400013e)	// timing select
#define DEVICE_COMMAND_CFF	(0xb4000140)	// CFD function
#define DEVICE_COMMAND_CFD	(0xb4000142)	// CFD delay
#define DEVICE_COMMAND_IHW	(0xb4000144)	// inhibit width
#define DEVICE_COMMAND_PZD	(0xb4000156)	// analog pole zero
#define DEVICE_DOMMAND_BRS	(0xb400015c)	// baseline restorer select
#define DEVICE_DOMMAND_LWC	(0xb4000160)	// list wave compress
#define DEVICE_DOMMAND_LWD	(0xb4000162)	// list wave delay
#define DEVICE_DOMMAND_LWN	(0xb4000164)	// list wave data
#define DEVICE_DOMMAND_LFS	(0xb400016a)	// list format
#define DEVICE_DOMMAND_BRM	(0xb400017a)	// baseline count manual

// status
#define DEVICE_STATUS_RTM	(0xb400001c)	// real time
#define DEVICE_STATUS_ICR	(0xb400012c)	// input count rate(cps)
#define DEVICE_STATUS_TCR	(0xb4000130)	// throughput count rate(cps)
#define DEVICE_STATUS_CLT	(0xb4000146)	// ch live time
#define DEVICE_STATUS_CDT	(0xb400014c)	// ch dead time


//******************* parameter ********************
// measurement mode
#define DEVICE_PARAM_MOD_HIST	(0)		// histogram
#define DEVICE_PARAM_MOD_LIST	(1)		// list
#define DEVICE_PARAM_MOD_WAVE	(2)		// wave

// measurement start/stop
#define DEVICE_PARAM_AQS_STOP	(0)		// stop
#define DEVICE_PARAM_AQS_START	(1)		// start

// DAC monitor
#define DEVICE_PARAM_DAC_CH1_PAMP	(0)	// CH1 pre amp
#define DEVICE_PARAM_DAC_CH1_FAST	(1)	// CH1 fast
#define DEVICE_PARAM_DAC_CH1_SLOW	(2)	// CH1 slow
#define DEVICE_PARAM_DAC_CH1_CFD	(3)	// CH1 CFD

// analog coarse gain
#define DEVICE_PARAM_ACG_x1		(0)		// x1
#define DEVICE_PARAM_ACG_x2		(1)		// x2
#define DEVICE_PARAM_ACG_x5		(2)		// x5
#define DEVICE_PARAM_ACG_x10	(3)		// x10

// ADC gain
#define DEVICE_PARAM_ADG_16384	(0)		// 16384
#define DEVICE_PARAM_ADG_8192	(1)		// 8192
#define DEVICE_PARAM_ADG_4096	(2)		// 4096
#define DEVICE_PARAM_ADG_2048	(3)		// 2048
#define DEVICE_PARAM_ADG_1024	(4)		// 1024
#define DEVICE_PARAM_ADG_512	(5)		// 512
#define DEVICE_PARAM_ADG_256	(6)		// 256

// Fast diff
#define DEVICE_PARAM_FFD_EXT	(0)		// Ext(cancel)
#define DEVICE_PARAM_FFD_20		(1)		// 20
#define DEVICE_PARAM_FFD_50		(2)		// 50
#define DEVICE_PARAM_FFD_100	(3)		// 100
#define DEVICE_PARAM_FFD_200	(4)		// 200

// Fast integral
#define DEVICE_PARAM_FFI_EXT	(0)		// Ext(cancel)
#define DEVICE_PARAM_FFI_20		(1)		// 20
#define DEVICE_PARAM_FFI_50		(2)		// 50
#define DEVICE_PARAM_FFI_100	(3)		// 100
#define DEVICE_PARAM_FFI_200	(4)		// 200

// polarity
#define DEVICE_PARAM_POL_NON	(0)		// non-inverse
#define DEVICE_PARAM_POL_INV	(1)		// inverse

// digital coarse gain
#define DEVICE_PARAM_DCG_x1		(0)		// x1
#define DEVICE_PARAM_DCG_x2		(1)		// x2
#define DEVICE_PARAM_DCG_x4		(2)		// x4
#define DEVICE_PARAM_DCG_x8		(3)		// x8
#define DEVICE_PARAM_DCG_x16	(4)		// x16
#define DEVICE_PARAM_DCG_x32	(5)		// x32
#define DEVICE_PARAM_DCG_x64	(6)		// x64
#define DEVICE_PARAM_DCG_x128	(7)		// x128

// timing select
#define DEVICE_PARAM_TMS_LET	(0)		// LET
#define DEVICE_PARAM_TMS_CFD	(1)		// CFD

// CFD function
#define DEVICE_PARAM_CFF_0_125	(1)		// 0.125
#define DEVICE_PARAM_CFF_0_25	(2)		// 0.25
#define DEVICE_PARAM_CFF_0_375	(3)		// 0.375
#define DEVICE_PARAM_CFF_0_5	(4)		// 0.5
#define DEVICE_PARAM_CFF_0_625	(5)		// 0.625
#define DEVICE_PARAM_CFF_0_75	(6)		// 0.75
#define DEVICE_PARAM_CFF_0_875	(7)		// 0.875

// CFD delay
#define DEVICE_PARAM_CFD_10		(0)		// 10ns
#define DEVICE_PARAM_CFD_20		(1)		// 20ns
#define DEVICE_PARAM_CFD_30		(2)		// 30ns
#define DEVICE_PARAM_CFD_40		(3)		// 40ns
#define DEVICE_PARAM_CFD_50		(4)		// 50ns
#define DEVICE_PARAM_CFD_60		(5)		// 60ns
#define DEVICE_PARAM_CFD_70		(6)		// 70ns
#define DEVICE_PARAM_CFD_80		(7)		// 80ns

// baseline restorer select
#define DEVICE_PARAM_BRS_LOW	(0)		// Low
#define DEVICE_PARAM_BRS_MID	(1)		// Middle
#define DEVICE_PARAM_BRS_HIGH	(2)		// High
#define DEVICE_PARAM_BRS_MAN	(3)		// Manual

// list wave compress
#define DEVICE_PARAM_LWC_10		(0)		// 10ns
#define DEVICE_PARAM_LWC_20		(1)		// 20ns
#define DEVICE_PARAM_LWC_40		(2)		// 40ns
#define DEVICE_PARAM_LWC_80		(3)		// 80ns
#define DEVICE_PARAM_LWC_160	(4)		// 160ns
#define DEVICE_PARAM_LWC_320	(5)		// 320ns
#define DEVICE_PARAM_LWC_640	(6)		// 640ns
#define DEVICE_PARAM_LWC_1280	(7)		// 1280ns

// list format
#define DEVICE_PARAM_LFS_LIST	(0)		// List
#define DEVICE_PARAM_LFS_LPW	(1)		// List+Pileup Wave

#endif // __COMMAND__
