//*****************************************************************************
// Description     : Declaration and macro definition for SiTCP communication
// Target Device   : APV8016A
// Target Platform : Linux, C
// Date            : Nov. 2020
// Version         : 1.0
//*****************************************************************************
#ifndef __SITCP_H__
#define __SITCP_H__

#include "sys_compatible.h"


//******************** macro definition ********************
// command communication: header common part
#define SITCP_VER_TYPE	((unsigned char)(0xff))	// version, type

// command communication: read command flag
#define SITCP_READ_REQ_CMDFLAG	((unsigned char)(0xc0))	// request
#define SITCP_READ_ACK_CMDFLAG	((unsigned char)(0xc8))	// acknowledge

// command communication: write command flag
#define SITCP_WRITE_REQ_CMDFLAG	((unsigned char)(0x80))	// request
#define SITCP_WRITE_ACK_CMDFLAG	((unsigned char)(0x88))	// acknowledge

// command communication: identifier
#define SITCP_READ_ID	(6)		// read
#define SITCP_WRITE_ID	(7)		// write

// command communication: length
#define SITCP_DATA_LEN	(2) 	// data length at header
#define SITCP_FORMAT_LEN_ADDR_ONLY	(8)		// data format for address only
		// header(=4) + address(=4)
#define SITCP_FORMAT_LEN_WITH_PARAM	(10)	// data format for adddress and parameter
		// header(=4) + address(=4) + parameter(=2)


//******************** structure type definition ********************
// header for command communication
typedef struct sitcp_header {
	unsigned char ver_type;	// version(4bit), type(4bit)
	unsigned char cmd_flag;	// command(4bit), flag(4bit)
	unsigned char id;		// identifier
	unsigned char length;	// data length(byte)
} SITCP_HEADER;

// data format for address only (for Status command)
typedef struct sitcp_format_addr_only {
	SITCP_HEADER header;
	unsigned int address;	// command address(32bit)
} SITCP_FORMAT_ADDR_ONLY;

// data format for address and parameter
typedef struct sitcp_format_with_param {
	SITCP_HEADER header;
	unsigned int address;	// command address(32bit)
	unsigned short param;	// parameter(16bit)
} SITCP_FORMAT_WITH_PARAM;


//******************** prototype declaration ********************
extern int sitcp_cmd_init(unsigned short, int *);
extern int sitcp_data_init(char *, int *);

extern unsigned short sitcp_read_16bit(int, unsigned int, int *);
extern unsigned int   sitcp_read_32bit(int, unsigned int, int *);
extern unsigned qword sitcp_read_48bit(int, unsigned int, int *);

extern int sitcp_write_16bit(int, unsigned int, unsigned short);
extern int sitcp_write_48bit(int, unsigned int, unsigned qword);

extern unsigned qword sitcp_hton64(unsigned qword);
extern unsigned qword sitcp_ntoh64(unsigned qword);


#endif // __SITCP_H__

